package java.lang;

import java.io.Serializable;

public final class Boolean implements Serializable, Comparable<Boolean>
{
    public static final Boolean TRUE;
    public static final Boolean FALSE;
    public static final Class<Boolean> TYPE;
    private final boolean value;
    private static final long serialVersionUID = -3665804199014368530L;
    
    public Boolean(boolean value) {
        this.value = value;
    }
    
    public Boolean(String s) {
        this(parseBoolean(s));
    }
    
    public static boolean parseBoolean(String s) {
        return s != null && s.equalsIgnoreCase("true");
    }
    
    public boolean booleanValue() {
        return this.value;
    }
    
    public static Boolean valueOf(boolean b) {
        return b ? Boolean.TRUE : Boolean.FALSE;
    }
    
    public static Boolean valueOf(String s) {
        return parseBoolean(s) ? Boolean.TRUE : Boolean.FALSE;
    }
    
    public static String toString(boolean b) {
        return b ? "true" : "false";
    }
    
    @Override
    public String toString() {
        return this.value ? "true" : "false";
    }
    
    @Override
    public int hashCode() {
        return hashCode(this.value);
    }
    
    public static int hashCode(boolean b) {
        return b ? 1231 : 1237;
    }
    
    @Override
    public boolean equals(Object o) {
        return o instanceof Boolean && this.value == (boolean)o;
    }
    
    public static boolean getBoolean(String s) {
        boolean boolean1 = false;
        try {
            boolean1 = parseBoolean(System.getProperty(s));
        }
        catch (IllegalArgumentException | NullPointerException ex) {}
        return boolean1;
    }
    
    @Override
    public int compareTo(Boolean b) {
        return compare(this.value, b.value);
    }
    
    public static int compare(boolean b, boolean b2) {
        return (b == b2) ? 0 : (b ? 1 : -1);
    }
    
    public static boolean logicalAnd(boolean b, boolean b2) {
        return b && b2;
    }
    
    public static boolean logicalOr(boolean b, boolean b2) {
        return b || b2;
    }
    
    public static boolean logicalXor(boolean b, boolean b2) {
        return b ^ b2;
    }
    
    static {
        TRUE = new Boolean(true);
        FALSE = new Boolean(false);
        TYPE = Class.getPrimitiveClass("boolean");
    }
}
